@@ -8,7 +8,7 @@
 
 #define TAGGED_CLASS    "CBOR::Free::Tagged"
 
-#define IS_SCALAR_REFERENCE(value) SvTYPE(SvRV(value)) < SVt_INVLIST
+#define IS_SCALAR_REFERENCE(value) SvTYPE(SvRV(value)) <= SVt_PVMG
 
 static const unsigned char NUL = 0;
 static const unsigned char CBOR_NULL_U8  = CBOR_NULL;
@@ -313,7 +313,7 @@ void _encode( pTHX_ SV *value, encode_ctx *encode_state ) {
             }
         }
     }
-    else if (IS_SCALAR_REFERENCE(value)) {
+    else if (encode_state->encode_scalar_refs && IS_SCALAR_REFERENCE(value)) {
         SV *referent = SvRV(value);
 
         _encode_tag( aTHX_ CBOR_TAG_INDIRECTION, referent, encode_state );
